@@ -19,12 +19,11 @@ use Carp;
 
 our @ISA = qw(XML::DTD::Parser);
 
-our $VERSION = '0.03';
+our $VERSION = '0.01';
 
 # Constructor
 sub new {
   my $arg = shift;
-  my $val = shift; # Parser is validating
 
   my $cls = ref($arg) || $arg;
   my $obj = ref($arg) && $arg;
@@ -41,7 +40,6 @@ sub new {
     $self->{'ATTLISTS'} = {};
     $self->{'ENTMAN'} = XML::DTD::EntityManager->new;
     $self->{'INCFLAG'} = 0;
-    $self->{'VALIDATING'} = $val;
   }
   bless $self, $cls;
   return $self;
@@ -52,9 +50,8 @@ sub new {
 sub fread {
   my $self = shift;
   my $fh = shift;
-  my $uri = shift;
 
-  my $r = $self->parse($fh, '', $uri);
+  my $r = $self->parse($fh);
   return ($r eq '')?1:0;
 }
 
@@ -63,9 +60,8 @@ sub fread {
 sub sread {
   my $self = shift;
   my $str = shift;
-  my $uri = shift;
 
-  my $r = $self->parse(undef, $str, $uri);
+  my $r = $self->parse(undef, $str);
   return ($r eq '')?1:0;
 }
 
@@ -168,7 +164,7 @@ XML::DTD - Perl module for parsing XML DTDs
 
   my $dtd = new XML::DTD;
   open(FH,'<file.dtd');
-  $dtd->fread(*FH);
+  my $dtd->fread(*FH);
   close(FH);
   $dtd->fwrite(*STDOUT);
 
@@ -185,26 +181,21 @@ XML::DTD - Perl module for parsing XML DTDs
 
 =item B<new>
 
-  $dtd = new XML::DTD [ ($val) ];
+  $dtd = new XML::DTD;
 
 Constructs a new XML::DTD object.
 
-Its parser will be validating, and hence will make parameter entity
-substitutions, if the argument C<$val> is present and non-zero.
-
 =item B<fread>
 
-  $dtd->fread(*FILEHANDLE [, $uri]);
+  $dtd->fread(*FILEHANDLE);
 
-Parse a DTD file. If the URI is passed, it is used as the URI for
-the document entity.
+Parse a DTD file.
 
 =item B<sread>
 
-  $dtd->sread($string [, $uri]);
+  $dtd->sread($string);
 
-Parse DTD text in a string. If the URI is passed, it is used as the URI for
-the document entity.
+Parse DTD text in a string.
 
 =item B<fwrite>
 
@@ -266,9 +257,4 @@ Copyright (C) 2004-2006 by Brendt Wohlberg
 This library is available under the terms of the GNU General Public
 License (GPL), described in the GPL file included in this distribution.
 
-=head1 ACKNOWLEDGMENTS
-
-Peter Lamb E<lt>Peter.Lamb@csiro.auE<gt> added fetching of external
-entities and improved entity substitution.
-
 =cut
