@@ -7,7 +7,7 @@ use Carp;
 
 our @ISA = qw();
 
-our $VERSION = '0.02';
+our $VERSION = '0.01';
 
 
 # Constructor
@@ -103,9 +103,6 @@ sub _parse {
   my $ws1 = shift;
   my $ws2 = shift;
 
-  $name = $self->_entitymanager->peexpend($name)
-    if ($name =~ /^%([\w\.:\-_]+);$/);
-
   $self->{'NAME'} = $name;
   $self->{'ATTTYPE'} = $type;
   $self->{'DEFAULTDECL'} = $dflt;
@@ -202,8 +199,4 @@ Copyright (C) 2004-2006 by Brendt Wohlberg
 This library is available under the terms of the GNU General Public
 License (GPL), described in the GPL file included in this distribution.
 
-=head1 ACKNOWLEDGMENTS
-
-Peter Lamb E<lt>Peter.Lamb@csiro.auE<gt> improved entity substitution.
-
 =cut
